from qfunction.fundamentals import *
#from qfunction.quantum.quantum_circuit import QuantumCircuit